@@ -8,3 +8,16 @@ insane_longitude_warning = function() {
             call. = FALSE)
   }
 }
+
+#' @title Pipe operator
+#' @description
+#' See \code{magrittr::\link[magrittr:pipe]{\%>\%}} for details.
+#'
+#' @name %>%
+#' @usage lhs \%>\% rhs
+#' @rdname pipe
+#' @keywords internal
+#' @importFrom magrittr %>%
+#' @return `NULL` (this is the magrittr pipe operator)
+#' @export
+NULL
